Page 58 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 58

Home

    for blood that they had created, had eliminated all sense
    of loyalty or justice, even to one another. The list of the
    victims of their own folly is so long that we will only

    The Duke of Orleans, the man who had pledged his
    honor, his fortune, and his blood to the revolution, in the
    end sacrificed them all. Used as a tool, cheated, and
    ruined by the conspiracy he espoused, he was finally led
    to the guillotine amid the insults and jeers of the
    populace of whom he had been represented as an idol.

    Mirabeau, an early leader of the Revolution, died
    suddenly just two days after having turned against his
    former friends.

    Danton, the man who helped plan and carry out the
    massacres of September, was sentenced to death and
    executed at the guillotine.

    Marat, who had called for the death of so many, was
    stabbed through the heart by a woman while in his own
    home. Even after his death an unholy fascination
    centered around him. Crowds of worshipers knelt around
    his body, blaspheming Christ and crying out, "Oh sacred
    heart of Marat!" Added to the display of Satanic
    admiration was the fact that his body decayed with
    amazing rapidity immediately after his death.

    Carrier, who ordered the murder of innocent children,

    Robespierre, the chief architect of the events from
    October 1793 on, was the last, and died a hideous death.

    53

    The French Revolution

    name a few.

    was executed by the guillotine surrounded by a jeering

    multitude.